@@ -17,7 +17,7 @@ use App::VTide::Hooks;
 use Path::Tiny;
 use YAML::Syck qw/ LoadFile DumpFile /;
 
-our $VERSION = version->new('0.0.6');
+our $VERSION = version->new('0.0.7');
 
 has config => (
     is      => 'rw',
@@ -83,6 +83,12 @@ sub run {
         ],
     );
 
+    if ( ! $self->sub_commands->{ $opt->cmd } ) {
+        unshift @ARGV, $opt->cmd;
+        $opt->cmd( $ENV{VTIDE_DIR} ? 'edit' : 'start' );
+        $opt->files(\@ARGV);
+    }
+
     my $subcommand = eval { $self->load_subcommand( $opt->cmd, $opt ) };
     if ( ! $subcommand ) {
         $subcommand = $self->load_subcommand( $ENV{VTIDE_DIR} ? 'edit' : 'start', $opt );
@@ -160,7 +166,7 @@ App::VTide - A vim/tmux based IDE for the terminal
 
 =head1 VERSION
 
-This documentation refers to App::VTide version 0.0.6
+This documentation refers to App::VTide version 0.0.7
 
 =head1 SYNOPSIS
 
